==> opencart_v1.2.6.zip: opencart_v1.2.6/upload/catalog/language/english/checkout/confirm.php <==
<?php
// Heading 
$_['heading_title']                  = 'Checkout Confirmation';

// Text 
$_['text_basket']                    = 'Basket';
$_['text_shipping']                  = 'Shipping';
$_['text_payment']                   = 'Payment';
$_['text_confirm']                   = 'Confirm';
$_['text_shipping_address']          = 'Shipping Address';
$_['text_shipping_method']           = 'Shipping Method';
$_['text_payment_address']           = 'Payment Address'; 
$_['text_payment_method']            = 'Payment Method';
$_['text_comment']                   = 'Your Comments';
$_['text_change']                    = 'Change';
$_['text_coupon']                    = 'Success: Your coupon discount has been applied!';

// Columns
$_['column_product']                 = 'Product';
$_['column_model']                   = 'Model';
$_['column_quantity']                = 'Quantity';
$_['column_price']                   = 'Price';
$_['column_total']                   = 'Total';	

// Entry
$_['entry_coupon']                   = 'Coupon:';

// Mail
$_['mail_new_order_subject']         = '%s - Order %s';
$_['mail_new_order_greeting']        = 'Thank your for interest in Your Store products. Your order has been received and will be processed once payment has been confirmed.';
$_['mail_new_order_order']           = 'Order ID:';
$_['mail_new_order_date_added']      = 'Date Ordered:';
$_['mail_new_order_order_status']    = 'Order Status:';
$_['mail_new_order_invoice']         = 'To view your order click on the link below:';
$_['mail_new_order_download']        = 'Once your payment has been confirmed you can click on the link below to access your downloadable products:';
$_['mail_new_order_comment']         = 'The comments for your order are:';
$_['mail_new_order_product']         = 'Products:';
$_['mail_new_order_total']           = 'Totals:';
$_['mail_new_order_footer']          = 'Please reply to this email if you have any questions.';
$_['mail_update_order_subject']      = '%s - Order Update %s';
$_['mail_update_order_order']        = 'Order ID:';
$_['mail_update_order_date_added']   = 'Date Ordered:';
$_['mail_update_order_order_status'] = 'Your order has been updated to the following status:';
$_['mail_update_order_comment']      = 'The comments for your order are:';
$_['mail_update_order_invoice']      = 'To view your order click on the link below:';
$_['mail_update_order_footer']       = 'Please reply to this email if you have any questions.';

// Error
$_['error_coupon']                   = 'Error: Coupon is ethier invalid, expired or reached its usage limit!';	
?>

==> opencart_v1.3.0.zip: opencart_v1.3.0/upload/catalog/language/english/checkout/confirm.php <==
<?php
// Heading 
$_['heading_title']                  = 'Checkout Confirmation';

// Text 
$_['text_basket']                    = 'Basket';
$_['text_shipping']                  = 'Shipping';
$_['text_payment']                   = 'Payment';
$_['text_confirm']                   = 'Confirm';
$_['text_shipping_address']          = 'Shipping Address';
$_['text_shipping_method']           = 'Shipping Method';
$_['text_payment_address']           = 'Payment Address'; 
$_['text_payment_method']            = 'Payment Method';
$_['text_comment']                   = 'Your Comments';
$_['text_change']                    = 'Change';
$_['text_coupon']                    = 'Success: Your coupon discount has been applied!';

// Columns
$_['column_product']                 = 'Product';
$_['column_model']                   = 'Model';
$_['column_quantity']                = 'Quantity';
$_['column_price']                   = 'Price';
$_['column_total']                   = 'Total';	

// Entry
$_['entry_coupon']                   = 'Coupon:';

// Mail
$_['mail_new_order_subject']         = '%s - Order %s';
$_['mail_new_order_greeting']        = 'Thank your for interest in %s products. Your order has been received and will be processed once payment has been confirmed.';
$_['mail_new_order_received']        = 'You have received an order.';
$_['mail_new_order_order']           = 'Order ID:';
$_['mail_new_order_date_added']      = 'Date Ordered:';
$_['mail_new_order_order_status']    = 'Order Status:';
$_['mail_new_order_invoice']         = 'To view your order click on the link below:';
$_['mail_new_order_download']        = 'Once your payment has been confirmed you can click on the link below to access your downloadable products:';
$_['mail_new_order_comment']         = 'The comments for your order are:';
$_['mail_new_order_product']         = 'Products:';
$_['mail_new_order_total']           = 'Totals:';
$_['mail_new_order_footer']          = 'Please reply to this email if you have any questions.';
$_['mail_update_order_subject']      = '%s - Order Update %s';
$_['mail_update_order_order']        = 'Order ID:';
$_['mail_update_order_date_added']   = 'Date Ordered:';
$_['mail_update_order_order_status'] = 'Your order has been updated to the following status:';
$_['mail_update_order_comment']      = 'The comments for your order are:';
$_['mail_update_order_invoice']      = 'To view your order click on the link below:';
$_['mail_update_order_footer']       = 'Please reply to this email if you have any questions.';

// Error
$_['error_coupon']                   = 'Error: Coupon is either invalid, expired or reached its usage limit!';	
?>
